@@ -1,7 +1,7 @@
 import torch
 import tqdm
 from ml_benchmark.config import MLPHyperparameter
-from ml_benchmark.latency_tracker import latency_decorator
+from ml_benchmark.decorators import latency_decorator, validation_latency_decorator
 from ml_benchmark.workload.mnist.mlp import MLP
 from ml_benchmark.workload.objective import Objective
 from sklearn.metrics import classification_report
@@ -11,6 +11,7 @@ from sklearn.metrics import classification_report
 class MLPObjective(Objective):
 
     def __init__(self, epochs, train_loader, val_loader, test_loader, input_size, output_size) -> None:
+        super().__init__()
         self.train_loader = train_loader
         self.val_laoder = val_loader
         self.test_loader = test_loader
@@ -26,6 +27,9 @@ class MLPObjective(Objective):
         print(self.hyperparameters)
         self.hyperparameters.update(hyperparameters)
         print(self.hyperparameters)
+    
+    def get_hyperparameters(self) -> dict:
+        return self.hyperparameters
 
     def set_device(self, device_str: str = None):
         if device_str:
@@ -50,7 +54,7 @@ class MLPObjective(Objective):
             epoch_losses.append(sum(batch_losses)/len(batch_losses))
         return {"train_loss": epoch_losses}
 
-    @latency_decorator
+    @validation_latency_decorator
     def validate(self):
         self.model.eval()
         self.model = self.model.to(self.device)
